HEADERS = {
    "User-Agent": "Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:63.0) Gecko/20100101 Firefox/63.0",
    "Referer": "https://ichart.instiz.net",
}

URL = "http://www.instiz.net/iframe_ichart_score.htm"

CHANGES = {
    "arrow1": "up",
    "arrow2": "down",
    "arrow3": "none",
    "arrow4": "new",
    "arrow5": "new",
}

